# Copyright 2011 Yelp
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This module provides a sqlite-backed dictionary conforming to the dbm
interface, along with a shelve class that wraps the dict and provides
serialization for it.
"""

__author__ = 'Jason Fennell <jfennell@yelp.com>'
__version__ = '0.1.2'

import sqlite3dbm.dbm as dbm
import sqlite3dbm.sshelve as sshelve

# Expose `open` and `error` here
from sqlite3dbm.dbm import *
